%import_data2MATLAB
% Imports pressure, temperature, time data into MATLAB for plotting & analysis
% and plots graphs and PNG files.
%
% LAST UPDATED by Andy French Nov 2019

function import_data2MATLAB

%Set fontsize for graphs
fsize = 16;

%

%Load data (four columns, two header lines)
[P_kPa1,Ta_degC1,Tliq_degC1,t1] = textread('datalog run1.txt',...
    '%f%f%f%f',...
    'delimiter',' ',...
    'emptyvalue',NaN,...
    'headerlines',2);
[P_kPa2,Ta_degC2,Tliq_degC2,t2] = textread('datalog run2.txt',...
    '%f%f%f%f',...
    'delimiter',' ',...
    'emptyvalue',NaN,...
    'headerlines',2);
[P_kPa3,Ta_degC3,Tliq_degC3,t3] = textread('datalog run3.txt',...
    '%f%f%f%f',...
    'delimiter',' ',...
    'emptyvalue',NaN,...
    'headerlines',2);

%Assemble data into MATLAB arrays
P_kPa = [P_kPa1;P_kPa2;P_kPa3];
Ta_degC = [Ta_degC1;Ta_degC2;Ta_degC3];
Tliq_degC = [Tliq_degC1;Tliq_degC2;Tliq_degC3];
t = [t1;t2+t1(end);t3+t1(end)+t2(end)];
save('T p t datalog','P_kPa','Ta_degC','Tliq_degC','t');

%Plot pressure evs time
plot(t,P_kPa);
xlabel('Time /s','fontsize',fsize);
ylabel('Pressure /kPa','fontsize',fsize);
title('Bell jar pressure /kPa','fontsize',fsize);
set(gca,'fontsize',fsize);
grid on;
print(gcf,'P vs t.png','-dpng','-r300');
clf;

%Plot temperatures vs time
plot(t,Ta_degC,t,Tliq_degC);
xlabel('Time /s','fontsize',fsize);
ylabel('Temperature / ^oC','fontsize',fsize);
title('Thermocouple temperature / ^oC vs time','fontsize',fsize);
legend({'Ambient','Liquid'},'fontsize',fsize,'location','southeast');
set(gca,'fontsize',fsize);
grid on;
print(gcf,'T vs t.png','-dpng','-r300');
close(gcf);

%End of code