%Import data from Excel, make basic plots, and determine boiling pressures
%and temperatures
function import_data_from_excel

%Fontsize for graphs
fsize = 18;

%Import Excel sheet 'Tboil vs pressure.xlsx'
disp(' ... Importing raw data from Excel sheet');
[num,txt,raw] = xlsread( 'Boiling point of water vs pressure.xlsx' );

%Extract data
T_degC = num(3:end,2);  %Temperature inside water in round bottom flask in bell jar
Ta_degC = num(3:end,1); %Ambient laboratory temperature
P_kPa = num(3:end,3);   %Air pressure in bell jar
t_s = num(3:end,4);     %Time /s

%Step through p vs t and find minima. These pressures correpond to the
%pressures at boiling.
disp(' ... Finding boiling pressures and temperatures');
tmin = []; Pboil = []; Tboil = []; M = 42;
for n = (M+1) : ( length(t_s)-M )
    test = 1;
    for m=1:M
        test = test * ( P_kPa(n-m) > P_kPa(n) ) * ( P_kPa(n+m) > P_kPa(n) ) * ( P_kPa(n) < 100 ); 
    end
    if test==1;
        tmin = [tmin,t_s(n)];
        Pboil = [Pboil,P_kPa(n)];
        Tboil = [Tboil,T_degC(n)];
    end
end

%Plot Pressure vs time
subplot(2,1,1);
plot(t_s,P_kPa); ylim([0,110]); set(gca,'fontsize',fsize); grid on;
xlabel('time /s','fontsize',fsize); ylabel('Pressure /kPa','fontsize',fsize);
title('Bell jar air pressure vs time'); hold on; plot( tmin, Pboil, '*' );    

%Plot Temperature vs time
subplot(2,1,2);
plot(t_s,Ta_degC,t_s,T_degC); set(gca,'fontsize',fsize); grid on;
xlabel('time /s','fontsize',fsize); ylabel('Temperature /^oC','fontsize',fsize);
legend({'Ambient','Water in flask'},'fontsize',fsize,'location','east');
title('Water and lab temperature vs time');
print(gcf,'p and T vs t.png','-dpng','-r300'); close(gcf);

%Save data .mat file
save('t T p data.mat','t_s','T_degC','Ta_degC','P_kPa','Tboil','tmin','Pboil' );

%End of code